@@ -1,7 +1,7 @@
 package Bencher::Scenario::WordListModules;
 
-our $DATE = '2017-01-25'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2018-02-20'; # DATE
+our $VERSION = '0.050'; # VERSION
 
 use 5.010001;
 use strict;
@@ -19,6 +19,8 @@ our $scenario = {
         {module=>'WordList::ID::KBBI'},
         {module=>'WordList::Phrase::EN::Proverb::TWW'},
         {module=>'WordList::Phrase::ID::Proverb::KBBI'},
+
+        {module=>'WordListC::Password::SecLists::10Million::Top100000'},
     ],
 };
 
@@ -37,7 +39,7 @@ Bencher::Scenario::WordListModules - Benchmark startup overhead of WordList::* m
 
 =head1 VERSION
 
-This document describes version 0.04 of Bencher::Scenario::WordListModules (from Perl distribution Bencher-Scenario-WordListModules), released on 2017-01-25.
+This document describes version 0.050 of Bencher::Scenario::WordListModules (from Perl distribution Bencher-Scenario-WordListModules), released on 2018-02-20.
 
 =head1 SYNOPSIS
 
@@ -63,12 +65,14 @@ L<WordList::EN::Enable> 0.03
 
 L<WordList::EN::SGB> 0.03
 
-L<WordList::ID::KBBI> 0.03
+L<WordList::ID::KBBI> 0.04
 
 L<WordList::Phrase::EN::Proverb::TWW> 0.03
 
 L<WordList::Phrase::ID::Proverb::KBBI> 0.03
 
+L<WordListC::Password::SecLists::10Million::Top100000> 0.001
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -115,27 +119,34 @@ L<WordList::Phrase::ID::Proverb::KBBI>
 
 
 
+=item * WordListC::Password::SecLists::10Million::Top100000 (perl_code)
+
+L<WordListC::Password::SecLists::10Million::Top100000>
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
+Run on: perl: I<< v5.26.1 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 18.3 >>, OS kernel: I<< Linux version 4.10.0-38-generic >>.
 
 Benchmark with default options (C<< bencher -m WordListModules >>):
 
  #table1#
- +----------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | participant                            | proc_private_dirty_size (kB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +----------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | WordList::EN::SGB                      | 916                          | 4.2                | 16             |       6.6 |                    1.5 |        1   | 3.1e-05 |      21 |
- | WordList::Phrase::ID::Proverb::KBBI    | 844                          | 4.1                | 16             |       6.6 |                    1.5 |        1   | 3.2e-05 |      23 |
- | WordList::EN::CountryNames::SingleWord | 916                          | 4.2                | 16             |       6.5 |                    1.4 |        1   | 2.6e-05 |      20 |
- | WordList::EN::CountryNames             | 916                          | 4.2                | 16             |       6.5 |                    1.4 |        1   | 3.1e-05 |      22 |
- | WordList::Phrase::EN::Proverb::TWW     | 924                          | 4.2                | 16             |       6.5 |                    1.4 |        1   | 2.7e-05 |      20 |
- | WordList::ID::KBBI                     | 920                          | 4.1                | 16             |       6.5 |                    1.4 |        1   | 3.2e-05 |      37 |
- | WordList::EN::Enable                   | 916                          | 4.2                | 16             |       6.4 |                    1.3 |        1   | 2.5e-05 |      20 |
- | perl -e1 (baseline)                    | 916                          | 4.2                | 16             |       5.1 |                    0   |        1.3 | 1.3e-05 |      20 |
- +----------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ +-----------------------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant                                         | proc_private_dirty_size (kB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +-----------------------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | WordList::ID::KBBI                                  | 952                          | 4.3                | 16             |       7   |      1.1               |        1   | 2.9e-05 |      21 |
+ | WordList::Phrase::EN::Proverb::TWW                  | 948                          | 4.2                | 16             |       7   |      1.1               |        1   | 1.9e-05 |      20 |
+ | WordList::Phrase::ID::Proverb::KBBI                 | 916                          | 4.3                | 16             |       6.9 |      1                 |        1   | 2.1e-05 |      20 |
+ | WordList::EN::CountryNames::SingleWord              | 940                          | 4.2                | 16             |       6.9 |      1                 |        1   | 3.4e-05 |      22 |
+ | WordList::EN::CountryNames                          | 944                          | 4.3                | 16             |       6.8 |      0.899999999999999 |        1   | 3.2e-05 |      21 |
+ | WordList::EN::Enable                                | 944                          | 4.3                | 16             |       6.7 |      0.8               |        1   | 3.1e-05 |      30 |
+ | WordList::EN::SGB                                   | 940                          | 4.2                | 16             |       6.7 |      0.8               |        1   | 3.2e-05 |      30 |
+ | WordListC::Password::SecLists::10Million::Top100000 | 844                          | 4.1                | 16             |       6.7 |      0.8               |        1   | 1.5e-05 |      20 |
+ | perl -e1 (baseline)                                 | 940                          | 4.3                | 16             |       5.9 |      0                 |        1.2 | 2.9e-05 |      23 |
+ +-----------------------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
@@ -166,7 +177,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2018, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
