@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::WordListModules;
 
-our $VERSION = 0.04; # VERSION
+our $VERSION = "0.050"; # VERSION
 
 our $results = [
   [
@@ -8,92 +8,103 @@ our $results = [
     "OK",
     [
       {
-        errors => 3.1e-05,
-        mod_overhead_time => 1.5,
-        participant => "WordList::EN::SGB",
-        proc_private_dirty_size => 916,
-        proc_rss_size => 4.2,
+        errors => 2.9e-05,
+        mod_overhead_time => 1.1,
+        participant => "WordList::ID::KBBI",
+        proc_private_dirty_size => 952,
+        proc_rss_size => 4.3,
         proc_size => 16,
         samples => 21,
-        time => 6.6,
+        time => 7,
         vs_slowest => 1,
       },
       {
-        errors => 3.2e-05,
-        mod_overhead_time => 1.5,
-        participant => "WordList::Phrase::ID::Proverb::KBBI",
-        proc_private_dirty_size => 844,
-        proc_rss_size => 4.1,
-        proc_size => 16,
-        samples => 23,
-        time => 6.6,
-        vs_slowest => 1,
-      },
-      {
-        errors => 2.6e-05,
-        mod_overhead_time => 1.4,
-        participant => "WordList::EN::CountryNames::SingleWord",
-        proc_private_dirty_size => 916,
+        errors => 1.9e-05,
+        mod_overhead_time => 1.1,
+        participant => "WordList::Phrase::EN::Proverb::TWW",
+        proc_private_dirty_size => 948,
         proc_rss_size => 4.2,
         proc_size => 16,
         samples => 20,
-        time => 6.5,
+        time => 7,
         vs_slowest => 1,
       },
       {
-        errors => 3.1e-05,
-        mod_overhead_time => 1.4,
-        participant => "WordList::EN::CountryNames",
+        errors => 2.1e-05,
+        mod_overhead_time => 1,
+        participant => "WordList::Phrase::ID::Proverb::KBBI",
         proc_private_dirty_size => 916,
+        proc_rss_size => 4.3,
+        proc_size => 16,
+        samples => 20,
+        time => 6.9,
+        vs_slowest => 1,
+      },
+      {
+        errors => 3.4e-05,
+        mod_overhead_time => 1,
+        participant => "WordList::EN::CountryNames::SingleWord",
+        proc_private_dirty_size => 940,
         proc_rss_size => 4.2,
         proc_size => 16,
         samples => 22,
-        time => 6.5,
-        vs_slowest => 1,
-      },
-      {
-        errors => 2.7e-05,
-        mod_overhead_time => 1.4,
-        participant => "WordList::Phrase::EN::Proverb::TWW",
-        proc_private_dirty_size => 924,
-        proc_rss_size => 4.2,
-        proc_size => 16,
-        samples => 20,
-        time => 6.5,
+        time => 6.9,
         vs_slowest => 1,
       },
       {
         errors => 3.2e-05,
-        mod_overhead_time => 1.4,
-        participant => "WordList::ID::KBBI",
-        proc_private_dirty_size => 920,
+        mod_overhead_time => 0.899999999999999,
+        participant => "WordList::EN::CountryNames",
+        proc_private_dirty_size => 944,
+        proc_rss_size => 4.3,
+        proc_size => 16,
+        samples => 21,
+        time => 6.8,
+        vs_slowest => 1,
+      },
+      {
+        errors => 3.1e-05,
+        mod_overhead_time => 0.8,
+        participant => "WordList::EN::Enable",
+        proc_private_dirty_size => 944,
+        proc_rss_size => 4.3,
+        proc_size => 16,
+        samples => 30,
+        time => 6.7,
+        vs_slowest => 1,
+      },
+      {
+        errors => 3.2e-05,
+        mod_overhead_time => 0.8,
+        participant => "WordList::EN::SGB",
+        proc_private_dirty_size => 940,
+        proc_rss_size => 4.2,
+        proc_size => 16,
+        samples => 30,
+        time => 6.7,
+        vs_slowest => 1,
+      },
+      {
+        errors => 1.5e-05,
+        mod_overhead_time => 0.8,
+        participant => "WordListC::Password::SecLists::10Million::Top100000",
+        proc_private_dirty_size => 844,
         proc_rss_size => 4.1,
         proc_size => 16,
-        samples => 37,
-        time => 6.5,
-        vs_slowest => 1,
-      },
-      {
-        errors => 2.5e-05,
-        mod_overhead_time => 1.3,
-        participant => "WordList::EN::Enable",
-        proc_private_dirty_size => 916,
-        proc_rss_size => 4.2,
-        proc_size => 16,
         samples => 20,
-        time => 6.4,
+        time => 6.7,
         vs_slowest => 1,
       },
       {
-        errors => 1.3e-05,
+        errors => 2.9e-05,
         mod_overhead_time => 0,
         participant => "perl -e1 (baseline)",
-        proc_private_dirty_size => 916,
-        proc_rss_size => 4.2,
+        proc_private_dirty_size => 940,
+        proc_rss_size => 4.3,
         proc_size => 16,
-        samples => 20,
-        time => 5.1,
-        vs_slowest => 1.3,
+        samples => 23,
+        time => 5.9,
+        vs_slowest => 1.2,
       },
     ],
     {
@@ -103,6 +114,7 @@ our $results = [
                                             scenario_module => "WordListModules",
                                           },
       "func.bencher_version"           => undef,
+      "func.code_startup"              => undef,
       "func.cpu_info"                  => [
                                             {
                                               address_width                => 64,
@@ -153,7 +165,6 @@ our $results = [
                                                                                 "xtopology",
                                                                                 "nonstop_tsc",
                                                                                 "aperfmperf",
-                                                                                "eagerfpu",
                                                                                 "pni",
                                                                                 "pclmulqdq",
                                                                                 "dtes64",
@@ -164,6 +175,7 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
+                                                                                "sdbg",
                                                                                 "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
@@ -183,12 +195,8 @@ our $results = [
                                                                                 "lahf_lm",
                                                                                 "abm",
                                                                                 "3dnowprefetch",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
+                                                                                "intel_pt",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
@@ -208,6 +216,11 @@ our $results = [
                                                                                 "adx",
                                                                                 "smap",
                                                                                 "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "4096 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -216,7 +229,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2617.234,
+                                              speed                        => 2658.752,
                                               stepping                     => 4,
                                             },
                                             {
@@ -268,7 +281,6 @@ our $results = [
                                                                                 "xtopology",
                                                                                 "nonstop_tsc",
                                                                                 "aperfmperf",
-                                                                                "eagerfpu",
                                                                                 "pni",
                                                                                 "pclmulqdq",
                                                                                 "dtes64",
@@ -279,6 +291,7 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
+                                                                                "sdbg",
                                                                                 "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
@@ -298,12 +311,8 @@ our $results = [
                                                                                 "lahf_lm",
                                                                                 "abm",
                                                                                 "3dnowprefetch",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
+                                                                                "intel_pt",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
@@ -323,6 +332,11 @@ our $results = [
                                                                                 "adx",
                                                                                 "smap",
                                                                                 "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "4096 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -331,7 +345,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2711.351,
+                                              speed                        => 2666.613,
                                               stepping                     => 4,
                                             },
                                             {
@@ -383,7 +397,6 @@ our $results = [
                                                                                 "xtopology",
                                                                                 "nonstop_tsc",
                                                                                 "aperfmperf",
-                                                                                "eagerfpu",
                                                                                 "pni",
                                                                                 "pclmulqdq",
                                                                                 "dtes64",
@@ -394,6 +407,7 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
+                                                                                "sdbg",
                                                                                 "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
@@ -413,12 +427,8 @@ our $results = [
                                                                                 "lahf_lm",
                                                                                 "abm",
                                                                                 "3dnowprefetch",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
+                                                                                "intel_pt",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
@@ -438,6 +448,11 @@ our $results = [
                                                                                 "adx",
                                                                                 "smap",
                                                                                 "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "4096 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -446,7 +461,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2757.671,
+                                              speed                        => 2443.676,
                                               stepping                     => 4,
                                             },
                                             {
@@ -498,7 +513,6 @@ our $results = [
                                                                                 "xtopology",
                                                                                 "nonstop_tsc",
                                                                                 "aperfmperf",
-                                                                                "eagerfpu",
                                                                                 "pni",
                                                                                 "pclmulqdq",
                                                                                 "dtes64",
@@ -509,6 +523,7 @@ our $results = [
                                                                                 "est",
                                                                                 "tm2",
                                                                                 "ssse3",
+                                                                                "sdbg",
                                                                                 "fma",
                                                                                 "cx16",
                                                                                 "xtpr",
@@ -528,12 +543,8 @@ our $results = [
                                                                                 "lahf_lm",
                                                                                 "abm",
                                                                                 "3dnowprefetch",
-                                                                                "ida",
-                                                                                "arat",
                                                                                 "epb",
-                                                                                "pln",
-                                                                                "pts",
-                                                                                "dtherm",
+                                                                                "intel_pt",
                                                                                 "tpr_shadow",
                                                                                 "vnmi",
                                                                                 "flexpriority",
@@ -553,6 +564,11 @@ our $results = [
                                                                                 "adx",
                                                                                 "smap",
                                                                                 "xsaveopt",
+                                                                                "dtherm",
+                                                                                "ida",
+                                                                                "arat",
+                                                                                "pln",
+                                                                                "pts",
                                                                               ],
                                               L2_cache                     => { max_cache_size => "4096 KB" },
                                               manufacturer                 => "GenuineIntel",
@@ -561,61 +577,62 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2600.007,
+                                              speed                        => 2574.499,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 1.60923504829407,
+      "func.elapsed_time"              => 1.88844013214111,
       "func.module_startup"            => 1,
       "func.module_versions"           => {
-                                            "__PACKAGE__" => 1.034,
-                                            "Bencher::Scenario::WordListModules" => undef,
-                                            "Benchmark::Dumb" => "0.10",
-                                            "Devel::Platform::Info" => 0.16,
-                                            "perl" => "v5.24.0",
-                                            "Sys::Info" => 0.78,
-                                            "WordList::EN::CountryNames" => 0.04,
-                                            "WordList::EN::CountryNames::SingleWord" => 0.04,
-                                            "WordList::EN::Enable" => 0.03,
-                                            "WordList::EN::SGB" => 0.03,
-                                            "WordList::ID::KBBI" => 0.03,
-                                            "WordList::Phrase::EN::Proverb::TWW" => 0.03,
-                                            "WordList::Phrase::ID::Proverb::KBBI" => 0.03,
+                                            "__PACKAGE__"                                         => "1.040",
+                                            "Bencher::Scenario::WordListModules"                  => undef,
+                                            "Benchmark::Dumb"                                     => 0.111,
+                                            "Devel::Platform::Info"                               => 0.16,
+                                            "perl"                                                => "v5.26.1",
+                                            "Sys::Info"                                           => 0.78,
+                                            "WordList::EN::CountryNames"                          => 0.04,
+                                            "WordList::EN::CountryNames::SingleWord"              => 0.04,
+                                            "WordList::EN::Enable"                                => 0.03,
+                                            "WordList::EN::SGB"                                   => 0.03,
+                                            "WordList::ID::KBBI"                                  => 0.04,
+                                            "WordList::Phrase::EN::Proverb::TWW"                  => 0.03,
+                                            "WordList::Phrase::ID::Proverb::KBBI"                 => 0.03,
+                                            "WordListC::Password::SecLists::10Million::Top100000" => 0.001,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 7]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 8]],
       "func.platform_info"             => {
                                             archname => "x86_64",
-                                            codename => "rosa",
+                                            codename => "sylvia",
                                             is32bit  => 0,
                                             is64bit  => 1,
-                                            kernel   => "linux-3.19.0-32-generic",
+                                            kernel   => "linux-4.10.0-38-generic",
                                             kname    => "Linux",
-                                            kvers    => "3.19.0-32-generic",
+                                            kvers    => "4.10.0-38-generic",
                                             osflag   => "linux",
                                             oslabel  => "LinuxMint",
                                             osname   => "GNU/Linux",
-                                            osvers   => 17.3,
+                                            osvers   => 18.3,
                                             source   => {
                                                           "cat /etc/.issue" => "",
-                                                          "cat /etc/issue"  => "Linux Mint 17.3 Rosa \\n \\l",
-                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 17.3 Rosa\nRelease:\t17.3\nCodename:\trosa",
-                                                          "uname -a"        => "Linux backpacker 3.19.0-32-generic #37~14.04.1-Ubuntu SMP Thu Oct 22 09:41:40 UTC 2015 x86_64 x86_64 x86_64 GNU/Linux",
+                                                          "cat /etc/issue"  => "Linux Mint 18.3 Sylvia \\n \\l",
+                                                          "lsb_release -a"  => "Distributor ID:\tLinuxMint\nDescription:\tLinux Mint 18.3 Sylvia\nRelease:\t18.3\nCodename:\tsylvia",
+                                                          "uname -a"        => "Linux backpacker 4.10.0-38-generic #42~16.04.1-Ubuntu SMP Tue Oct 10 16:32:20 UTC 2017 x86_64 x86_64 x86_64 GNU/Linux",
                                                           "uname -m"        => "x86_64",
                                                           "uname -o"        => "GNU/Linux",
-                                                          "uname -r"        => "3.19.0-32-generic",
+                                                          "uname -r"        => "4.10.0-38-generic",
                                                           "uname -s"        => "Linux",
                                                         },
                                           },
       "func.precision"                 => 0.005,
       "func.scenario_module"           => "Bencher::Scenario::WordListModules",
-      "func.scenario_module_md5sum"    => "7aff5e4b73ff35e36d93a8eafcaed0e8",
-      "func.scenario_module_mtime"     => 1452189399,
-      "func.scenario_module_sha1sum"   => "ebd887b68501156d8e492ed5fe452eaff4247320",
-      "func.scenario_module_sha256sum" => "4bf951fbce5d3f7a81735bc3e4cf4b230be33694d82c1be14e305023b9bcd4e7",
-      "func.time_end"                  => 1485325361.573,
+      "func.scenario_module_md5sum"    => "a7c92794773877d57ab6f50976dbec8b",
+      "func.scenario_module_mtime"     => 1519115828,
+      "func.scenario_module_sha1sum"   => "6be938537615e92d4b30029e93895a6c585aaf06",
+      "func.scenario_module_sha256sum" => "f051c35dbbf32006fb329d99ae8db8bbb23e7df3296b1410d295a14c94206385",
+      "func.time_end"                  => 1519116019.46781,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1485325359.96377,
+      "func.time_start"                => 1519116017.57937,
       "table.field_aligns"             => [
                                             "left",
                                             "left",
